@@ -438,7 +438,8 @@ test_that("wflow_html sends warning if fig.path is set by user", {
   html <- rmarkdown::render(rmd, quiet = TRUE)
   expect_true(fs::file_exists(html))
   html_lines <- readLines(html)
-  expect_true(sum(stringr::str_detect(html_lines, "<code>fig.path</code>")) == 1)
+  warnings_fig.path <- stringr::str_detect(html_lines, "<code>fig.path</code>")
+  expect_identical(sum(warnings_fig.path), 1L)
 
   # If set globally, a warning should be generated for each plot (in this case 3)
   rmd2 <- file.path(tmp_dir, "file2.Rmd")
@@ -446,8 +447,43 @@ test_that("wflow_html sends warning if fig.path is set by user", {
   html2 <- rmarkdown::render(rmd2, quiet = TRUE)
   expect_true(fs::file_exists(html2))
   html_lines2 <- readLines(html2)
-  expect_true(sum(stringr::str_detect(html_lines2, "<code>fig.path</code>")) == 3)
+  warnings_fig.path2 <- stringr::str_detect(html_lines2, "<code>fig.path</code>")
+  expect_identical(sum(warnings_fig.path2), 3L)
+})
 
+test_that("wflow_html sends warning for outdated version of reticulate", {
+
+  skip_on_cran()
+
+  test_reticulate <-
+    requireNamespace("reticulate", quietly = TRUE) &&
+    reticulate::py_available(initialize = TRUE) &&
+    reticulate::py_module_available("matplotlib")
+
+  if (!test_reticulate) skip("Python not configured to test reticulate")
+
+  tmp_dir <- tempfile()
+  fs::dir_create(tmp_dir)
+  tmp_dir <- workflowr:::absolute(tmp_dir)
+  on.exit(unlink(tmp_dir, recursive = TRUE))
+
+  rmd <- file.path(tmp_dir, "file.Rmd")
+  fs::file_copy("files/test-wflow_html/python-figure.Rmd", rmd)
+  html <- rmarkdown::render(rmd, quiet = TRUE)
+  expect_true(fs::file_exists(html))
+  html_lines <- readLines(html)
+  warnings_reticulate <- stringr::str_detect(html_lines,
+                                             "<a href=\"https://cran.r-project.org/package=reticulate\">reticulate</a>")
+
+  if (utils::packageVersion("reticulate") < "1.14.9000") {
+    expect_identical(sum(warnings_reticulate), 2L)
+  } else {
+    expect_identical(sum(warnings_reticulate), 0L)
+  }
+
+  # fig.path warning should also still be sent
+  warnings_fig.path <- stringr::str_detect(html_lines, "<code>fig.path</code>")
+  expect_identical(sum(warnings_fig.path), 1L)
 })
 
 # Test cache_hook --------------------------------------------------------------
@@ -581,7 +617,7 @@ test_that("Rmd file without title does not generate pandoc2 warning", {
   on.exit(fs::file_delete(rmd))
   fs::file_create(rmd)
   observed <- test_pandoc_warning(rmd)
-  expect_identical(observed, character())
+  expect_false(any(stringr::str_detect(observed, "nonempty")))
 })
 
 test_that("Rmd file with title defined in pandoc_args does not generate pandoc2 warning", {
@@ -598,7 +634,7 @@ test_that("Rmd file with title defined in pandoc_args does not generate pandoc2
              "")
   writeLines(lines, con = rmd)
   observed <- test_pandoc_warning(rmd, output_format = NULL)
-  expect_identical(observed, character())
+  expect_false(any(stringr::str_detect(observed, "nonempty")))
 })
 
 test_that("Rmd file with defined title does not generate pandoc2 warning", {
@@ -610,7 +646,7 @@ test_that("Rmd file with defined title does not generate pandoc2 warning", {
   lines <- c("---", "title: something", "---", "")
   writeLines(lines, con = rmd)
   observed <- test_pandoc_warning(rmd)
-  expect_identical(observed, character())
+  expect_false(any(stringr::str_detect(observed, "nonempty")))
 })
 
 test_that("Rmd file with defined pagetitle does not generate pandoc2 warning", {
@@ -622,7 +658,7 @@ test_that("Rmd file with defined pagetitle does not generate pandoc2 warning", {
   lines <- c("---", "pagetitle: something", "---", "")
   writeLines(lines, con = rmd)
   observed <- test_pandoc_warning(rmd)
-  expect_identical(observed, character())
+  expect_false(any(stringr::str_detect(observed, "nonempty")))
 })
 
 test_that("Rmd file with defined title and pagetitle does not generate pandoc2 warning", {
@@ -634,7 +670,7 @@ test_that("Rmd file with defined title and pagetitle does not generate pandoc2 w
   lines <- c("---", "title: something", "pagetitle: else", "---", "")
   writeLines(lines, con = rmd)
   observed <- test_pandoc_warning(rmd)
-  expect_identical(observed, character())
+  expect_false(any(stringr::str_detect(observed, "nonempty")))
 })
 
 test_that("add_pagetitle adds metadata pagetitle if missing title", {
