@@ -2,6 +2,10 @@ context("wflow_rename")
 
 # Setup ------------------------------------------------------------------------
 
+source("setup.R")
+
+skip_on_cran_windows()
+
 library("git2r")
 
 cwd <- getwd()
