@@ -2,17 +2,9 @@ context("wflow_use_gitlab")
 
 # Setup ------------------------------------------------------------------------
 
-test_setup <- function(path = tempfile()) {
-  suppressMessages(
-    wflow_start(path, change_wd = FALSE,
-                user.name = "Test Name", user.email = "test@email"))
-  path <- workflowr:::absolute(path)
-  return(path)
-}
+source("setup.R")
 
-test_teardown <- function(path) {
-  unlink(path, recursive = TRUE, force = TRUE)
-}
+skip_on_cran_windows()
 
 # Test wflow_use_gitlab --------------------------------------------------------
 
